summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/khello2
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /languages/cpp/app_templates/khello2
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'languages/cpp/app_templates/khello2')
-rw-r--r--languages/cpp/app_templates/khello2/app.h1
-rw-r--r--languages/cpp/app_templates/khello2/src-Makefile.am4
-rw-r--r--languages/cpp/app_templates/khello2/widget.cpp4
-rw-r--r--languages/cpp/app_templates/khello2/widget.h3
-rw-r--r--languages/cpp/app_templates/khello2/widgetbase.ui12
5 files changed, 13 insertions, 11 deletions
diff --git a/languages/cpp/app_templates/khello2/app.h b/languages/cpp/app_templates/khello2/app.h
index 678df7a3..fd0ca00b 100644
--- a/languages/cpp/app_templates/khello2/app.h
+++ b/languages/cpp/app_templates/khello2/app.h
@@ -17,6 +17,7 @@
class %{APPNAME} : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default Constructor
diff --git a/languages/cpp/app_templates/khello2/src-Makefile.am b/languages/cpp/app_templates/khello2/src-Makefile.am
index 4664fe84..7f9d7125 100644
--- a/languages/cpp/app_templates/khello2/src-Makefile.am
+++ b/languages/cpp/app_templates/khello2/src-Makefile.am
@@ -4,11 +4,11 @@ INCLUDES = $(all_includes)
# these are the headers for your project
noinst_HEADERS = %{APPNAMELC}.h
-# let automoc handle all of the meta source files (moc)
+# let autotqmoc handle all of the meta source files (tqmoc)
METASOURCES = AUTO
messages: rc.cpp
- $(EXTRACTRC) `find . -name \*.ui -o -name \*.rc` > rc.cpp
+ $(EXTRACTRC) `tqfind . -name \*.ui -o -name \*.rc` > rc.cpp
$(XGETTEXT) *.cpp -o $(podir)/%{APPNAMELC}.pot
KDE_ICON = AUTO
diff --git a/languages/cpp/app_templates/khello2/widget.h b/languages/cpp/app_templates/khello2/widget.h
index 50d7a721..3773456b 100644
--- a/languages/cpp/app_templates/khello2/widget.h
+++ b/languages/cpp/app_templates/khello2/widget.h
@@ -8,9 +8,10 @@
class %{APPNAME}Widget : public %{APPNAME}WidgetBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- %{APPNAME}Widget(TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+ %{APPNAME}Widget(TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
~%{APPNAME}Widget();
/*$PUBLIC_FUNCTIONS$*/
diff --git a/languages/cpp/app_templates/khello2/widgetbase.ui b/languages/cpp/app_templates/khello2/widgetbase.ui
index e6f5be3d..4540c922 100644
--- a/languages/cpp/app_templates/khello2/widgetbase.ui
+++ b/languages/cpp/app_templates/khello2/widgetbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>%{APPNAME}WidgetBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>%{APPNAMELC}widgetbase</cstring>
</property>
@@ -19,7 +19,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QPushButton" row="1" column="0">
+ <widget class="TQPushButton" row="1" column="0">
<property name="name">
<cstring>button</cstring>
</property>
@@ -27,7 +27,7 @@
<string>Click Me!</string>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>label</cstring>
</property>
@@ -45,8 +45,8 @@
<slot>button_clicked()</slot>
</connection>
</connections>
-<slots>
+<Q_SLOTS>
<slot>button_clicked()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/languages/cpp/app_templates/khello2/widget.cpp b/languages/cpp/app_templates/khello2/widget.cpp
index 266e894f..40e2d2bb 100644
--- a/languages/cpp/app_templates/khello2/widget.cpp
+++ b/languages/cpp/app_templates/khello2/widget.cpp
@@ -4,8 +4,8 @@
#include "%{APPNAMELC}widget.h"
-%{APPNAME}Widget::%{APPNAME}Widget(TQWidget* parent, const char* name, WFlags fl)
- : %{APPNAME}WidgetBase(parent,name,fl)
+%{APPNAME}Widget::%{APPNAME}Widget(TQWidget* tqparent, const char* name, WFlags fl)
+ : %{APPNAME}WidgetBase(tqparent,name,fl)
{}
%{APPNAME}Widget::~%{APPNAME}Widget()